==> jc-1.4.0.tar.gz: javax/crypto/KeyGeneratorSpi.h <==
// public abstract class javax.crypto.KeyGeneratorSpi

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class cc7a3e4916c6fcc1 javax_crypto_KeyGeneratorSpi

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_crypto_KeyGeneratorSpi_H_
#define _JC_javax_crypto_KeyGeneratorSpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_SecureRandom$object;
struct _jc_java_security_spec_AlgorithmParameterSpec$object;
struct _jc_javax_crypto_SecretKey$object;

// Typedefs
typedef struct _jc_javax_crypto_KeyGeneratorSpi$sub_refs	_jc_javax_crypto_KeyGeneratorSpi$sub_refs;
typedef struct _jc_javax_crypto_KeyGeneratorSpi$sub_nonrefs	_jc_javax_crypto_KeyGeneratorSpi$sub_nonrefs;
typedef struct _jc_javax_crypto_KeyGeneratorSpi$refs	_jc_javax_crypto_KeyGeneratorSpi$refs;
typedef struct _jc_javax_crypto_KeyGeneratorSpi$nonrefs	_jc_javax_crypto_KeyGeneratorSpi$nonrefs;
typedef struct _jc_javax_crypto_KeyGeneratorSpi$object	_jc_javax_crypto_KeyGeneratorSpi$object;

typedef const struct _jc_javax_crypto_KeyGeneratorSpi$vmethods	_jc_javax_crypto_KeyGeneratorSpi$vmethods;
typedef const struct _jc_javax_crypto_KeyGeneratorSpi$vtable	_jc_javax_crypto_KeyGeneratorSpi$vtable;
typedef const struct _jc_javax_crypto_KeyGeneratorSpi$vtype	_jc_javax_crypto_KeyGeneratorSpi$vtype;

// Constructors
extern void _jc_javax_crypto_KeyGeneratorSpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_crypto_KeyGeneratorSpi$object *);

// Virtual methods
extern struct _jc_object *_jc_javax_crypto_KeyGeneratorSpi$method$engineGenerateKey$d0f4d5ef5e22ea02(_jc_env *, struct _jc_javax_crypto_KeyGeneratorSpi$object *);
extern void _jc_javax_crypto_KeyGeneratorSpi$method$engineInit$ce17ad6b3fc98d82(_jc_env *, struct _jc_javax_crypto_KeyGeneratorSpi$object *, jint, struct _jc_java_security_SecureRandom$object *);
extern void _jc_javax_crypto_KeyGeneratorSpi$method$engineInit$3322302d28550a02(_jc_env *, struct _jc_javax_crypto_KeyGeneratorSpi$object *, struct _jc_java_security_SecureRandom$object *);
extern void _jc_javax_crypto_KeyGeneratorSpi$method$engineInit$5af33bc7d4d69573(_jc_env *, struct _jc_javax_crypto_KeyGeneratorSpi$object *, struct _jc_object *, struct _jc_java_security_SecureRandom$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_crypto_KeyGeneratorSpi$method_info$engineGenerateKey$d0f4d5ef5e22ea02;
extern _jc_method _jc_javax_crypto_KeyGeneratorSpi$method_info$engineInit$ce17ad6b3fc98d82;
extern _jc_method _jc_javax_crypto_KeyGeneratorSpi$method_info$engineInit$3322302d28550a02;
extern _jc_method _jc_javax_crypto_KeyGeneratorSpi$method_info$engineInit$5af33bc7d4d69573;

// Virtual methods structure
struct _jc_javax_crypto_KeyGeneratorSpi$vmethods {
	struct _jc_object	*(*engineGenerateKey$d0f4d5ef5e22ea02)(_jc_env *, struct _jc_javax_crypto_KeyGeneratorSpi$object *);
	void	(*engineInit$ce17ad6b3fc98d82)(_jc_env *, struct _jc_javax_crypto_KeyGeneratorSpi$object *, jint, struct _jc_java_security_SecureRandom$object *);
	void	(*engineInit$3322302d28550a02)(_jc_env *, struct _jc_javax_crypto_KeyGeneratorSpi$object *, struct _jc_java_security_SecureRandom$object *);
	void	(*engineInit$5af33bc7d4d69573)(_jc_env *, struct _jc_javax_crypto_KeyGeneratorSpi$object *, struct _jc_object *, struct _jc_java_security_SecureRandom$object *);
};

// Vtable
struct _jc_javax_crypto_KeyGeneratorSpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_crypto_KeyGeneratorSpi$vmethods	javax_crypto_KeyGeneratorSpi;
};

// Vtype
struct _jc_javax_crypto_KeyGeneratorSpi$vtype {
	_jc_type			type;
	_jc_javax_crypto_KeyGeneratorSpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_KeyGeneratorSpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_crypto_KeyGeneratorSpi$refs {
    _jc_javax_crypto_KeyGeneratorSpi$sub_refs	javax_crypto_KeyGeneratorSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_KeyGeneratorSpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_KeyGeneratorSpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_crypto_KeyGeneratorSpi$sub_nonrefs	javax_crypto_KeyGeneratorSpi;
};

// Object instance structure
struct _jc_javax_crypto_KeyGeneratorSpi$object {
	_jc_javax_crypto_KeyGeneratorSpi$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_KeyGeneratorSpi$vtype	*vtype;
	_jc_javax_crypto_KeyGeneratorSpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_KeyGeneratorSpi$vtype _jc_javax_crypto_KeyGeneratorSpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_KeyGeneratorSpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_KeyGeneratorSpi$class_object;

#endif	/* _JC_javax_crypto_KeyGeneratorSpi_H_ */

==> jc-1.4.6.tar.gz: javax/crypto/KeyGeneratorSpi.h <==
// public abstract class javax.crypto.KeyGeneratorSpi

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class cc7a3e4916c6fcc1 javax_crypto_KeyGeneratorSpi

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_crypto_KeyGeneratorSpi_H_
#define _JC_javax_crypto_KeyGeneratorSpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_SecureRandom$object;
struct _jc_java_security_spec_AlgorithmParameterSpec$object;
struct _jc_javax_crypto_SecretKey$object;

// Typedefs
typedef struct _jc_javax_crypto_KeyGeneratorSpi$sub_refs	_jc_javax_crypto_KeyGeneratorSpi$sub_refs;
typedef struct _jc_javax_crypto_KeyGeneratorSpi$sub_nonrefs	_jc_javax_crypto_KeyGeneratorSpi$sub_nonrefs;
typedef struct _jc_javax_crypto_KeyGeneratorSpi$refs	_jc_javax_crypto_KeyGeneratorSpi$refs;
typedef struct _jc_javax_crypto_KeyGeneratorSpi$nonrefs	_jc_javax_crypto_KeyGeneratorSpi$nonrefs;
typedef struct _jc_javax_crypto_KeyGeneratorSpi$object	_jc_javax_crypto_KeyGeneratorSpi$object;

typedef const struct _jc_javax_crypto_KeyGeneratorSpi$vmethods	_jc_javax_crypto_KeyGeneratorSpi$vmethods;
typedef const struct _jc_javax_crypto_KeyGeneratorSpi$vtable	_jc_javax_crypto_KeyGeneratorSpi$vtable;
typedef const struct _jc_javax_crypto_KeyGeneratorSpi$vtype	_jc_javax_crypto_KeyGeneratorSpi$vtype;

// Constructors
extern void _jc_javax_crypto_KeyGeneratorSpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_crypto_KeyGeneratorSpi$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_javax_crypto_KeyGeneratorSpi$method$engineGenerateKey$d0f4d5ef5e22ea02(_jc_env *, struct _jc_javax_crypto_KeyGeneratorSpi$object *) _JC_JCNI_ATTR;
extern void _jc_javax_crypto_KeyGeneratorSpi$method$engineInit$ce17ad6b3fc98d82(_jc_env *, struct _jc_javax_crypto_KeyGeneratorSpi$object *, jint, struct _jc_java_security_SecureRandom$object *) _JC_JCNI_ATTR;
extern void _jc_javax_crypto_KeyGeneratorSpi$method$engineInit$3322302d28550a02(_jc_env *, struct _jc_javax_crypto_KeyGeneratorSpi$object *, struct _jc_java_security_SecureRandom$object *) _JC_JCNI_ATTR;
extern void _jc_javax_crypto_KeyGeneratorSpi$method$engineInit$5af33bc7d4d69573(_jc_env *, struct _jc_javax_crypto_KeyGeneratorSpi$object *, struct _jc_object *, struct _jc_java_security_SecureRandom$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_crypto_KeyGeneratorSpi$method_info$engineGenerateKey$d0f4d5ef5e22ea02;
extern _jc_method _jc_javax_crypto_KeyGeneratorSpi$method_info$engineInit$ce17ad6b3fc98d82;
extern _jc_method _jc_javax_crypto_KeyGeneratorSpi$method_info$engineInit$3322302d28550a02;
extern _jc_method _jc_javax_crypto_KeyGeneratorSpi$method_info$engineInit$5af33bc7d4d69573;

// Virtual methods structure
struct _jc_javax_crypto_KeyGeneratorSpi$vmethods {
	struct _jc_object	*(*engineGenerateKey$d0f4d5ef5e22ea02)(_jc_env *, struct _jc_javax_crypto_KeyGeneratorSpi$object *) _JC_JCNI_ATTR;
	void	(*engineInit$ce17ad6b3fc98d82)(_jc_env *, struct _jc_javax_crypto_KeyGeneratorSpi$object *, jint, struct _jc_java_security_SecureRandom$object *) _JC_JCNI_ATTR;
	void	(*engineInit$3322302d28550a02)(_jc_env *, struct _jc_javax_crypto_KeyGeneratorSpi$object *, struct _jc_java_security_SecureRandom$object *) _JC_JCNI_ATTR;
	void	(*engineInit$5af33bc7d4d69573)(_jc_env *, struct _jc_javax_crypto_KeyGeneratorSpi$object *, struct _jc_object *, struct _jc_java_security_SecureRandom$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_crypto_KeyGeneratorSpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_crypto_KeyGeneratorSpi$vmethods	javax_crypto_KeyGeneratorSpi;
};

// Vtype
struct _jc_javax_crypto_KeyGeneratorSpi$vtype {
	_jc_type			type;
	_jc_javax_crypto_KeyGeneratorSpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_KeyGeneratorSpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_crypto_KeyGeneratorSpi$refs {
    _jc_javax_crypto_KeyGeneratorSpi$sub_refs	javax_crypto_KeyGeneratorSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_KeyGeneratorSpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_KeyGeneratorSpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_crypto_KeyGeneratorSpi$sub_nonrefs	javax_crypto_KeyGeneratorSpi;
};

// Object instance structure
struct _jc_javax_crypto_KeyGeneratorSpi$object {
	_jc_javax_crypto_KeyGeneratorSpi$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_KeyGeneratorSpi$vtype	*vtype;
	_jc_javax_crypto_KeyGeneratorSpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_KeyGeneratorSpi$vtype _jc_javax_crypto_KeyGeneratorSpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_KeyGeneratorSpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_KeyGeneratorSpi$class_object;

#endif	/* _JC_javax_crypto_KeyGeneratorSpi_H_ */
